@@ -9,12 +9,16 @@ import slow
 # rebuild using the templates. So try to import the compiled Bottleneck
 # functions to the top level, but move on if not successful.
 try:
-    from func import (nanmax, nanmin, nanmean, nanstd, nanvar, median,
+    from func import (nansum, nanmax, nanmin, nanmean, nanstd, nanvar, median,
                       nanmedian, nanargmin, nanargmax)
 except:
     pass
 try:
-    from move import move_nanmean
+    from move import (move_sum, move_nansum,
+                      move_mean, move_nanmean,
+                      move_std, move_nanstd,
+                      move_min, move_nanmin,
+                      move_max, move_nanmax)
 except:
     pass
 try:
