@@ -3,6 +3,7 @@ from bottleneck.src.template.template import template
 
 from median import median
 from nanmedian import nanmedian
+from nansum import nansum
 from nanmean import nanmean
 from nanvar import nanvar
 from nanstd import nanstd
@@ -14,6 +15,7 @@ from nanargmax import nanargmax
 funcs = {}
 funcs['median'] = median
 funcs['nanmedian'] = nanmedian
+funcs['nansum'] = nansum
 funcs['nanmean'] = nanmean
 funcs['nanvar'] = nanvar
 funcs['nanstd'] = nanstd
