@@ -14,6 +14,7 @@ floats = {}
 floats['dtypes'] = FLOAT_DTYPES
 floats['axisNone'] = False
 floats['force_output_dtype'] = 'NPINT'
+floats['reuse_non_nan_func'] = False
 
 floats['top'] = """
 @cython.boundscheck(False)
@@ -144,15 +145,21 @@ CANNOTCONVERT += "'cannot convert float NaN to integer'"
 
 def nanargmin(arr, axis=None):
     """
-    Return indices of the minimum values over an axis, ignoring NaNs.
+    Indices of the minimum values along an axis, ignoring NaNs.
     
     Parameters
     ----------
     a : array_like
         Input data.
-    axis : int, optional
-        Axis along which to operate. By default flattened input is used.
-    
+    axis : {int, None}, optional
+        Axis along which to operate. By default (axis=None) flattened input
+        is used.
+   
+    See also
+    --------
+    bottleneck.nanargmax: Indices of the maximum values along an axis.
+    bottleneck.nanmin: Minimum values along specified axis, ignoring NaNs.
+
     Returns
     -------
     index_array : ndarray
@@ -161,13 +168,13 @@ def nanargmin(arr, axis=None):
     Examples
     --------
     >>> a = np.array([[np.nan, 4], [2, 3]])
-    >>> np.argmin(a)
-    0
     >>> bn.nanargmin(a)
     2
-    >>> bn.nanargmin(a, axis=0)
+    >>> a.flat[1]
+    2.0
+    >>> bn.nanargmax(a, axis=0)
     array([1, 1])
-    >>> bn.nanargmin(a, axis=1)
+    >>> bn.nanargmax(a, axis=1)
     array([1, 0])
     
     """
@@ -223,18 +230,20 @@ def nanargmin_selector(arr, axis):
     0
 
     """
-    cdef np.ndarray a = np.array(arr, copy=False)
-    cdef int ndim = a.ndim
-    cdef np.dtype dtype = a.dtype
-    cdef int size = a.size
+    cdef np.ndarray a
+    if type(arr) is np.ndarray:
+        a = arr
+    else:    
+        a = np.array(arr, copy=False)
+    cdef int ndim = PyArray_NDIM(a)
+    cdef int dtype = PyArray_TYPE(a)
+    cdef int size = PyArray_SIZE(a)
     if size == 0:
         msg = "numpy.nanargmin() raises on size=0; so Bottleneck does too." 
         raise ValueError, msg
-    if axis != None:
+    if axis is not None:
         if axis < 0:
             axis += ndim
-        if (axis < 0) or (axis >= ndim):
-            raise ValueError, "axis(=%d) out of bounds" % axis
     else:
         a = a.ravel()
         axis = 0
@@ -243,10 +252,12 @@ def nanargmin_selector(arr, axis):
     try:
         func = nanargmin_dict[key]
     except KeyError:
+        if (axis < 0) or (axis >= ndim):
+            raise ValueError, "axis(=%d) out of bounds" % axis
         try:
             func = nanargmin_slow_dict[axis]
         except KeyError:
-            tup = (str(ndim), str(dtype), str(axis))
+            tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError, "Unsupported ndim/dtype/axis (%s/%s/%s)." % tup
     return func, a
 '''
